--
-- riot/Config.hs
-- 
-- Copyright (c) Tuomo Valkonen 2004.
--
-- This program is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--


module Config where

import Curses
import Version
import Char
import UI
import Style
import Entry(TagAction(..))

--
-- Keys
--

handle_key (KeyChar 'q') = e_quit
handle_key (KeyChar '\^R') = e_refresh
handle_key (KeyChar '.') = e_hscroll 2
handle_key (KeyChar ',') = e_hscroll (-2)
--handle_key (KeyDown)     = e_vscroll 2
--handle_key (KeyUp)       = e_vscroll (-2)
handle_key (KeyChar ' ') = e_pgdn
handle_key (KeyChar 'b') = e_pgup
handle_key (KeyChar 'u') = e_pgupentry
handle_key (KeyChar 'v') = e_pgdnentry
handle_key (KeyPPage)    = e_pgupentry
handle_key (KeyNPage)    = e_pgdnentry
handle_key (KeyHome)     = e_firstentry
handle_key (KeyEnd)      = e_lastentry
handle_key (KeyChar 'n') = e_nextentry
handle_key (KeyChar 'p') = e_preventry
handle_key (KeyUp)       = e_preventry
handle_key (KeyDown)     = e_nextentry
handle_key (KeyEnter)    = e_actentry
handle_key (KeyChar '\^M') = e_actentry
handle_key (KeyChar 'd') = e_delentry
handle_key (KeyChar 'e') = e_editentry
handle_key (KeyBackspace) = e_collapse
handle_key (KeyChar 'a') = e_newentry
handle_key (KeyChar 'r') = e_newunder
handle_key (KeyChar '\^_') = e_undo
handle_key (KeyChar '\^^') = e_redo
handle_key (KeyChar 't') = e_tag TagToggle
handle_key (KeyChar 'k') = e_submap "k" k_map
handle_key (KeyChar ';') = e_submap ";" tag_map
handle_key k             = e_fallback handle_key k

k_map (KeyChar 'u') = e_firstentry
k_map (KeyChar 'v') = e_lastentry
k_map (KeyChar 'd') = e_save
k_map k = e_fallback handle_key k

tag_map (KeyChar 't') = e_clear_tags
tag_map (KeyChar 'a') = e_move_tagged_after
tag_map (KeyChar 'b') = e_move_tagged_before
tag_map (KeyChar 'r') = e_move_tagged_under
tag_map (KeyChar 'd') = e_delete_tagged
tag_map k = e_fallback handle_key k


--
-- Help
--

topinfo_text = package++" "++version
               ++" ** q:quit, e:edit, a:new, r:new child, kd:save"

--
-- Styles
--

styles = [
     StyleSpec ("attr_infoline", (a_bold, c_green, c_blue)),
     StyleSpec ("attr_text",     (a_none, c_white, c_black)),
     StyleSpec ("attr_entry",    (a_none, c_white, c_black)),
     StyleSpec ("attr_entry_act",(a_bold, c_white, c_black)),
     StyleSpec ("attr_entry_sel",(a_reverse, c_cyan, c_black)),
     StyleSpec ("attr_entry_act_sel",(a_reverse, c_cyan, c_black)),
     StyleSpec ("attr_message",  (a_bold, c_white, c_black)),
     StyleSpec ("attr_error",    (a_bold, c_red, c_black))
     ]

